==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/mixer/adapter/stackdriver/Trace.java <==

package me.snowdrop.istio.mixer.adapter.stackdriver;

import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import io.fabric8.kubernetes.api.model.Doneable;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.sundr.builder.annotations.Buildable;
import io.sundr.builder.annotations.BuildableReference;
import io.sundr.builder.annotations.Inline;
import lombok.EqualsAndHashCode;
import lombok.ToString;


/**
 * 
 * 
 */
@JsonInclude(JsonInclude.Include.NON_EMPTY)
@JsonPropertyOrder({
    "apiVersion",
    "kind",
    "metadata",
    "sampleProbability"
})
@ToString
@EqualsAndHashCode
@Buildable(editableEnabled = false, validationEnabled = true, generateBuilderPackage = true, builderPackage = "io.fabric8.kubernetes.api.builder", inline = {
    @Inline(type = Doneable.class, prefix = "Doneable", value = "done")
}, refs = {
    @BuildableReference(ObjectMeta.class)
})
public class Trace implements Serializable
{

    /**
     * 
     * 
     */
    @JsonProperty("sampleProbability")
    @JsonPropertyDescription("")
    private Double sampleProbability;
    private final static long serialVersionUID = 6471927446304110809L;

    /**
     * No args constructor for use in serialization
     * 
     */
    public Trace() {
    }

    /**
     * 
     * @param sampleProbability
     */
    public Trace(Double sampleProbability) {
        super();
        this.sampleProbability = sampleProbability;
    }

    /**
     * 
     * 
     */
    @JsonProperty("sampleProbability")
    public Double getSampleProbability() {
        return sampleProbability;
    }

    /**
     * 
     * 
     */
    @JsonProperty("sampleProbability")
    public void setSampleProbability(Double sampleProbability) {
        this.sampleProbability = sampleProbability;
    }

}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/mixer/adapter/stackdriver/Trace.java <==

package me.snowdrop.istio.mixer.adapter.stackdriver;

import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import io.fabric8.kubernetes.api.model.Doneable;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.sundr.builder.annotations.Buildable;
import io.sundr.builder.annotations.BuildableReference;
import io.sundr.builder.annotations.Inline;
import lombok.EqualsAndHashCode;
import lombok.ToString;


/**
 * 
 * 
 */
@JsonInclude(JsonInclude.Include.NON_EMPTY)
@JsonPropertyOrder({
    "apiVersion",
    "kind",
    "metadata",
    "sampleProbability"
})
@ToString
@EqualsAndHashCode
@Buildable(editableEnabled = false, generateBuilderPackage = true, builderPackage = "io.fabric8.kubernetes.api.builder", inline = {
    @Inline(type = Doneable.class, prefix = "Doneable", value = "done")
}, refs = {
    @BuildableReference(ObjectMeta.class)
})
public class Trace implements Serializable
{

    /**
     * 
     * 
     */
    @JsonProperty("sampleProbability")
    @JsonPropertyDescription("")
    private Double sampleProbability;
    private final static long serialVersionUID = 6471927446304110809L;

    /**
     * No args constructor for use in serialization
     * 
     */
    public Trace() {
    }

    /**
     * 
     * @param sampleProbability
     */
    public Trace(Double sampleProbability) {
        super();
        this.sampleProbability = sampleProbability;
    }

    /**
     * 
     * 
     */
    @JsonProperty("sampleProbability")
    public Double getSampleProbability() {
        return sampleProbability;
    }

    /**
     * 
     * 
     */
    @JsonProperty("sampleProbability")
    public void setSampleProbability(Double sampleProbability) {
        this.sampleProbability = sampleProbability;
    }

}
